@@ -4,7 +4,7 @@
 #' the `predict_profile()` function.
 #'
 #' @param x an object of class `predict_profile_survival` to be plotted
-#' @param ... additional parameters, unused, currently ignored
+#' @param ... additional objects of class `"predict_profile_survival"` to be plotted together
 #' @param colors character vector containing the colors to be used for plotting variables (containing either hex codes "#FF69B4", or names "blue")
 #' @param variable_type character, either `"numerical"`, `"categorical"` or `NULL` (default), select only one type of variable for plotting, or leave `NULL` for all
 #' @param facet_ncol number of columns for arranging subplots
@@ -12,8 +12,10 @@
 #' @param numerical_plot_type character, either `"lines"`, or `"contours"` selects the type of numerical variable plots
 #' @param title character, title of the plot
 #' @param subtitle character, subtitle of the plot, `'default'` automatically generates "created for XXX, YYY models", where XXX and YYY are the explainer labels
+#' @param rug character, one of `"all"`, `"events"`, `"censors"`, `"none"` or `NULL`. Which times to mark on the x axis in `geom_rug()`.
+#' @param rug_colors character vector containing two colors (containing either hex codes `"#FF69B4"`, or names `"blue"`). The first color (red by default) will be used to mark event times, whereas the second (grey by default) will be used to mark censor times.
 #'
-#' @return A grid of `ggplot` objects arranged with the `gridExtra::grid.arrange` function.
+#' @return A collection of `ggplot` objects arranged with the `patchwork` package.
 #'
 #' @family functions for plotting 'predict_profile_survival' objects
 #'
@@ -47,12 +49,71 @@ plot.surv_ceteris_paribus <- function(x,
                                       variables = NULL,
                                       numerical_plot_type = "lines",
                                       title = "Ceteris paribus survival profile",
-                                      subtitle = "default") {
+                                      subtitle = "default",
+                                      rug = "all",
+                                      rug_colors = c("#dd0000", "#222222")) {
     if (!is.null(variable_type))
         check_variable_type(variable_type)
 
     check_numerical_plot_type(numerical_plot_type)
 
+    explanations_list <- c(list(x), list(...))
+    num_models <- length(explanations_list)
+
+
+    if (num_models == 1){
+        result <- prepare_ceteris_paribus_plots(x,
+                                                colors,
+                                                variable_type,
+                                                facet_ncol,
+                                                variables,
+                                                numerical_plot_type,
+                                                title,
+                                                subtitle,
+                                                rug,
+                                                rug_colors)
+        return(result)
+    }
+
+    return_list <- list()
+    labels <- list()
+    for (i in 1:num_models){
+        this_title <- unique(explanations_list[[i]]$result$`_label_`)
+        return_list[[i]] <- prepare_ceteris_paribus_plots(explanations_list[[i]],
+                                                          colors,
+                                                          variable_type,
+                                                          1,
+                                                          variables,
+                                                          numerical_plot_type,
+                                                          this_title,
+                                                          NULL,
+                                                          rug,
+                                                          rug_colors)
+        labels[[i]] <- c(this_title, rep("", length(return_list[[i]]$patches)-2))
+    }
+
+    labels <- unlist(labels)
+    return_plot <- patchwork::wrap_plots(return_list, nrow = 1, tag_level="keep") +
+                   patchwork::plot_annotation(title, tag_levels = list(labels)) & theme_default_survex()
+
+    return(return_plot)
+
+
+}
+
+
+prepare_ceteris_paribus_plots <- function(x,
+                                          colors = NULL,
+                                          variable_type = NULL,
+                                          facet_ncol = NULL,
+                                          variables = NULL,
+                                          numerical_plot_type = "lines",
+                                          title = "Ceteris paribus survival profile",
+                                          subtitle = "default",
+                                          rug = "all",
+                                          rug_colors = c("#dd0000", "#222222")){
+
+    rug_df <- data.frame(times = x$event_times, statuses = as.character(x$event_statuses), label = unique(x$result$`_label_`))
     obs <- x$variable_values
     x <- x$result
 
@@ -116,21 +177,25 @@ plot.surv_ceteris_paribus <- function(x,
         all_profiles = ceteris_paribus_with_observation,
         variables = all_variables,
         colors = colors,
-        numerical_plot_type = numerical_plot_type
-    )
+        numerical_plot_type = numerical_plot_type,
+        rug_df = rug_df,
+        rug = rug,
+        rug_colors = rug_colors)
 
     patchwork::wrap_plots(pl, ncol = facet_ncol) +
         patchwork::plot_annotation(title = title,
-                                   subtitle = subtitle) & DALEX::theme_drwhy()
+                                   subtitle = subtitle) & theme_default_survex()
 
 }
 
-#' @importFrom DALEX theme_drwhy
 #' @import ggplot2
 plot_individual_ceteris_paribus_survival <- function(all_profiles,
                                                      variables,
                                                      colors,
-                                                     numerical_plot_type) {
+                                                     numerical_plot_type,
+                                                     rug_df,
+                                                     rug,
+                                                     rug_colors) {
     pl <- lapply(variables, function(var) {
         df <- all_profiles[all_profiles$`_vname_` == var, ]
 
@@ -142,7 +207,7 @@ plot_individual_ceteris_paribus_survival <- function(all_profiles,
                                 mid = "#46bac2",
                                 high = "#371ea3")
             if (numerical_plot_type == "lines") {
-                with(df, {
+                base_plot <- with(df, {
                 ggplot(
                     df,
                     aes(
@@ -162,12 +227,12 @@ plot_individual_ceteris_paribus_survival <- function(all_profiles,
                     ) +
                     geom_line(data = df[df$`_real_point_`, ], color =
                                   "red", linewidth = 0.8, size = 0.8) +
-                    xlab("") + ylab("survival function value") + ylim(c(0, 1)) +
-                    theme_drwhy() +
+                    xlab("") + ylab("survival function value") + ylim(c(0, 1)) + xlim(c(0,NA))+
+                    theme_default_survex() +
                     facet_wrap(~`_vname_`)
                 })
             } else {
-                plt <- with(df, {
+                base_plot <- with(df, {
                         ggplot(
                     df,
                     aes(
@@ -180,21 +245,21 @@ plot_individual_ceteris_paribus_survival <- function(all_profiles,
                     scale_fill_manual(name = "SF value", values = grDevices::colorRampPalette(c("#c7f5bf", "#8bdcbe", "#46bac2", "#4378bf", "#371ea3"))(10),
                                     labels = seq(1, 0, -0.1)) +
                     guides(fill = guide_legend(nrow = 1, label.position = "top")) +
-                    xlab("") + ylab("variable value") +
-                    theme_drwhy() +
+                    xlab("") + ylab("variable value") + xlim(c(0,NA))+
+                    theme_default_survex() +
                     theme(legend.spacing = grid::unit(0.1, 'line')) +
                     facet_wrap(~`_vname_`)
                 })
                 if (any(df$`_real_point_`)) {
                     range_time <- range(df["_times_"])
                     var_val <- as.numeric(unique(df[df$`_real_point_`, "_x_"]))
-                    plt <- plt + geom_segment(aes(x = range_time[1], y = var_val, xend = range_time[2], yend = var_val), color = "red")
+                    base_plot <- base_plot + geom_segment(aes(x = range_time[1], y = var_val, xend = range_time[2], yend = var_val), color = "red")
                     }
-                plt
+                base_plot
                 }
         } else {
             n_colors <- length(unique(df$`_x_`))
-            pl <- with(df, {
+            base_plot <- with(df, {
                 ggplot(
                     df,
                     aes(
@@ -211,11 +276,17 @@ plot_individual_ceteris_paribus_survival <- function(all_profiles,
                           size = 0.8, linewidth = 0.8, linetype = "longdash") +
                 scale_color_manual(name = paste0(unique(df$`_vname_`), " value"),
                                    values = generate_discrete_color_scale(n_colors, colors)) +
-                theme_drwhy() +
-                xlab("") + ylab("survival function value") + ylim(c(0, 1)) +
+                theme_default_survex() +
+                xlab("") + ylab("survival function value") + ylim(c(0, 1)) + xlim(c(0,NA))+
                 facet_wrap(~`_vname_`) })
         }
+
+        return_plot <- add_rug_to_plot(base_plot, rug_df, rug, rug_colors)
+
+        return(return_plot)
     })
+
+    pl
 }
 
 
