@@ -7,7 +7,10 @@
 #' @param ... additional objects of class `surv_shap` to be plotted together
 #' @param title character, title of the plot
 #' @param subtitle character, subtitle of the plot, `'default'` automatically generates "created for XXX, YYY models", where XXX and YYY are the explainer labels
+#' @param max_vars maximum number of variables to be plotted (least important variables are ignored)
 #' @param colors character vector containing the colors to be used for plotting variables (containing either hex codes "#FF69B4", or names "blue")
+#' @param rug character, one of `"all"`, `"events"`, `"censors"`, `"none"` or `NULL`. Which times to mark on the x axis in `geom_rug()`.
+#' @param rug_colors character vector containing two colors (containing either hex codes "#FF69B4", or names "blue"). The first color (red by default) will be used to mark event times, whereas the second (grey by default) will be used to mark censor times.
 #'
 #' @return An object of the class `ggplot`.
 #'
@@ -30,13 +33,17 @@ plot.surv_shap <- function(x,
                            ...,
                            title = "SurvSHAP(t)",
                            subtitle = "default",
-                           colors = NULL) {
+                           max_vars = 7,
+                           colors = NULL,
+                           rug = "all",
+                           rug_colors = c("#dd0000", "#222222")) {
 
     dfl <- c(list(x), list(...))
 
     long_df <- lapply(dfl, function(x) {
         label <- attr(x, "label")
-        sv <- x$result
+        cols <- sort(head(order(x$aggregate, decreasing = TRUE), max_vars))
+        sv <- x$result[,cols]
         times <- x$eval_times
         transposed <- as.data.frame(cbind(times = times, sv))
         rownames(transposed) <- NULL
@@ -47,6 +54,13 @@ plot.surv_shap <- function(x,
         )
     })
 
+    transformed_rug_dfs <- lapply(dfl, function(x){
+        label <- attr(x, "label")
+        rug_df <- data.frame(times = x$event_times, statuses = as.character(x$event_statuses), label = label)
+    })
+
+    rug_df <- do.call(rbind, transformed_rug_dfs)
+
     long_df <- do.call(rbind, long_df)
     label <- unique(long_df$label)
 
@@ -59,14 +73,19 @@ plot.surv_shap <- function(x,
     y_lab <- "SurvSHAP(t) value"
 
 
-    with(long_df, {
+    base_plot <- with(long_df, {
     ggplot(data = long_df, aes(x = times, y = values, color = ind)) +
         geom_line(linewidth = 0.8, size = 0.8) +
         ylab(y_lab) + xlab("") +
+        xlim(c(0,NA))+
         labs(title = title, subtitle = subtitle) +
         scale_color_manual("variable", values = generate_discrete_color_scale(n_colors, colors)) +
-        theme_drwhy() +
+        theme_default_survex() +
         facet_wrap(~label, ncol = 1, scales = "free_y")
     })
 
+    return_plot <- add_rug_to_plot(base_plot, rug_df, rug, rug_colors)
+
+    return(return_plot)
+
 }
