@@ -1,6 +1,6 @@
 #' Helper functions for `model_parts.R`
 #'
-#' This function is used to calculate permutational feature imporance using
+#' This function is used to calculate permutational feature importance using
 #' a time-dependent metric. The result is the change in loss function at each
 #' time point after permuting each selected variable.
 #'
@@ -153,32 +153,34 @@ surv_feature_importance.default <- function(x,
             loss_function(observed, predicted, predicted_surv, times)
         })
 
-        cbind(data.frame(times = times), "_full_model_" = loss_full, loss_variables, "_baseline_" = loss_baseline)
+        times_temp_df <- data.frame("times" = times)
+        colnames(times_temp_df) <- "_times_"
+        cbind(times_temp_df, "_full_model_" = loss_full, loss_variables, "_baseline_" = loss_baseline)
     }
     # permute B times, collect results into single matrix
     raw <- do.call("rbind", replicate(B, loss_after_permutation(), simplify = FALSE))
-    raw$permutation <- rep(1:B, each = length(times))
-    tmp <- aggregate(. ~ times, raw, mean)
-    tmp$permutation <- rep(0, times = nrow(tmp))
+    raw$`_permutation_` <- rep(1:B, each = length(times))
+    tmp <- aggregate(. ~ `_times_`, raw, mean)
+    tmp$`_permutation_` <- rep(0, times = nrow(tmp))
 
     res <- rbind(tmp, raw)
     res$label <- rep(label, times = nrow(res))
 
     if (type %in% c("ratio", "difference")) {
-        res_full <- res[res$permutation == 0, c("times", "_full_model_")]
-        colnames(res_full) <- c("times", "reference")
-        res <- merge(res, res_full, by = "times")
-
+        res_full <- res[res$`_permutation_` == 0, c("_times_", "_full_model_")]
+        colnames(res_full) <- c("_times_", "_reference_")
+        res <- merge(res, res_full, by = "_times_")
+        res <- res[order(res$`_permutation_`, res$`_times_`),]
     }
     if (type == "ratio") {
 
-        res[, 2:(ncol(res) - 3)] <- res[, 2:(ncol(res) - 3)] / res[, (ncol(res))]
-        res$reference <- NULL
+        res[, 2:(ncol(res) - 3)] <- res[, 2:(ncol(res) - 3)] / res[["_reference_"]]
+        res$`_reference_` <- NULL
 
     }
     if (type == "difference") {
-        res[, 2:(ncol(res) - 3)] <- res[, 2:(ncol(res) - 3)] - res[, (ncol(res))]
-        res$reference <- NULL
+        res[, 2:(ncol(res) - 3)] <- res[, 2:(ncol(res) - 3)] - res[["_reference_"]]
+        res$`_reference_` <- NULL
     }
 
     # record details of permutations
