@@ -4,16 +4,13 @@
 #' @param new_observation a new observation for which predictions need to be explained
 #' @param ... additional parameters, passed to internal functions
 #' @param y_true a two element numeric vector or matrix of one row and two columns, the first element being the true observed time and the second the status of the observation, used for plotting
-#' @param calculation_method a character, only `"kernel"` is implemented for now.
+#' @param calculation_method a character, either `"kernelshap"` for use of `kernelshap` library (providing faster Kernel SHAP with refinements) or `"exact_kernel"` for exact Kernel SHAP estimation
 #' @param aggregation_method a character, either `"mean_absolute"` or `"integral"`, `"max_absolute"`, `"sum_of_squares"`
-#' @param path ignored, placeholder the not implemented `"sampling"` method
-#' @param B ignored, placeholder the not implemented `"sampling"` method
-#' @param exact ignored, placeholder the not implemented `"sampling"` method
 #'
 #' @return A list, containing the calculated SurvSHAP(t) results in the `result` field
 #'
 #' @section References:
-#' - \[1\] Krzyziński, Mateusz, et al. ["SurvSHAP(t): Time-dependent explanations of machine learning survival models."](https://arxiv.org/abs/2208.11080) arXiv preprint arXiv:2208.11080 (2022).
+#' - \[1\] Krzyziński, Mateusz, et al. ["SurvSHAP(t): Time-dependent explanations of machine learning survival models."](https://www.sciencedirect.com/science/article/pii/S0950705122013302) Knowledge-Based Systems 262 (2023): 110234
 #'
 #' @keywords internal
 surv_shap <- function(explainer,
@@ -21,18 +18,15 @@ surv_shap <- function(explainer,
                       ...,
                       y_true = NULL,
 
-                      calculation_method = "kernel",
+                      calculation_method = "kernelshap",
                       aggregation_method = "integral",
                       path = "average",
                       B = 25,
                       exact = FALSE
 ) {
     test_explainer(explainer, "surv_shap", has_data = TRUE, has_y = TRUE, has_survival = TRUE)
-    new_observation <- new_observation[, !colnames(new_observation) %in% colnames(explainer$y)]
-    if (ncol(explainer$data) != ncol(new_observation)) stop("New observation and data have different number of columns(variables)")
-
-    event_inds <- explainer$y[, 2]
-    event_times <- explainer$y[, 1]
+    new_observation <- new_observation[, colnames(new_observation) %in% colnames(explainer$data)]
+    if (ncol(explainer$data) != ncol(new_observation)) stop("New observation and data have different number of columns (variables)")
 
     if (!is.null(y_true)) {
         if (is.matrix(y_true)) {
@@ -44,9 +38,14 @@ surv_shap <- function(explainer,
         }
     }
 
-    res <- switch(calculation_method,
-                  "kernel" = shap_kernel(explainer, new_observation, aggregation_method, ...),
-                  stop("Only calculation method = `kernel` is implemented"))
+    res <- list()
+    res$eval_times <- explainer$times
+    res$variable_values <- new_observation
+
+    res$result <- switch(calculation_method,
+                         "exact_kernel" = shap_kernel(explainer, new_observation, ...),
+                         "kernelshap" = use_kernelshap(explainer, new_observation, ...),
+                         stop("Only `exact_kernel` and `kernelshap` calculation methods are implemented"))
 
     if (!is.null(y_true)) res$y_true <- c(y_true_time = y_true_time, y_true_ind = y_true_ind)
 
@@ -57,12 +56,9 @@ surv_shap <- function(explainer,
 }
 
 
-shap_kernel <- function(explainer, new_observation, aggregation_method,  ...) {
-
+shap_kernel <- function(explainer, new_observation, ...) {
 
     timestamps <- explainer$times
-
-
     p <- ncol(explainer$data)
 
     target_sf <- explainer$predict_survival_function(explainer$model, new_observation, timestamps)
@@ -77,14 +73,7 @@ shap_kernel <- function(explainer, new_observation, aggregation_method,  ...) {
 
     shap_values <- as.data.frame(shap_values, row.names = colnames(explainer$data))
     colnames(shap_values) <- paste("t=", timestamps, sep = "")
-
-
-    ret <- list()
-    ret$eval_times <- timestamps
-    ret$result <- t(shap_values)
-    ret$variable_values <- new_observation
-
-    return(ret)
+    return (t(shap_values))
 }
 
 generate_shap_kernel_weights <- function(permutations, p) {
@@ -103,11 +92,10 @@ generate_shap_kernel_weights <- function(permutations, p) {
 
 calculate_shap_values <- function(explainer, model, avg_survival_function, data, simplified_inputs, shap_kernel_weights, new_observation, timestamps) {
 
-    W <- diag(shap_kernel_weights)
+    w <- shap_kernel_weights
     X <- as.matrix(simplified_inputs)
 
-
-    R <- solve((t(X) %*% W %*% X)) %*% (t(X) %*% W)
+    R <- solve(t(sqrt(w) * X) %*% (sqrt(w) * X)) %*% t(X * w)
 
     y <- make_prediction_for_simplified_input(explainer, model, data, simplified_inputs, new_observation, timestamps)
 
@@ -129,7 +117,7 @@ make_prediction_for_simplified_input <- function(explainer, model, data, simplif
         X_tmp[, row] <- new_observation[, row]
         colnames(X_tmp) <- colnames(data)
 
-        apply(explainer$predict_survival_function(model, X_tmp, timestamps), 2, mean)
+        colMeans(explainer$predict_survival_function(model, X_tmp, timestamps))
 
     })
 
@@ -150,8 +138,24 @@ aggregate_surv_shap <- function(survshap, method) {
                times <- survshap$eval_times
                n <- length(x)
                i <- (x[1:(n - 1)] + x[2:n]) * diff(times) / 2
-               cumsum(c(0, i))[length(cumsum(c(0, i)))] / (max(times) - min(times))
+               sum(i) / (max(times) - min(times))
            })),
            stop("aggregation_method has to be one of `sum_of_squares`, `mean_absolute`, `max_absolute` or `integral`"))
 
 }
+
+
+use_kernelshap <- function(explainer, new_observation, ...){
+
+    predfun <- function(model, newdata){
+        explainer$predict_survival_function(model, newdata, times=explainer$times)
+    }
+
+    tmp_res <- kernelshap::kernelshap(explainer$model, new_observation, bg_X = explainer$data,
+               pred_fun = predfun, verbose=FALSE)
+
+    shap_values <- data.frame(t(sapply(tmp_res$S, cbind)))
+    colnames(shap_values) <- colnames(tmp_res$X)
+    rownames(shap_values) <- paste("t=", explainer$times, sep = "")
+    return(shap_values)
+}
