@@ -16,30 +16,33 @@ test_that("model_performance works", {
     expect_s3_class(cph_rot_perf, "list")
     expect_s3_class(rsf_rot_perf, "list")
 
-    expect_lte(cph_rot_perf$`C-index`, 1)
-    expect_gte(cph_rot_perf$`C-index`, 0)
-    expect_lte(cph_rot_perf$`Integrated C/D AUC`, 1)
-    expect_gte(cph_rot_perf$`Integrated C/D AUC`, 0)
-    expect_lte(cph_rot_perf$`Integrated Brier score`, 1)
-    expect_gte(cph_rot_perf$`Integrated Brier score`, 0)
-    expect_equal(length(cph_rot_perf$`Brier score`), length(cph_exp_rot$times))
-    expect_equal(length(cph_rot_perf$`C/D AUC`), length(cph_exp_rot$times))
+    expect_lte(cph_rot_perf$result$`C-index`, 1)
+    expect_gte(cph_rot_perf$result$`C-index`, 0)
+    expect_lte(cph_rot_perf$result$`Integrated C/D AUC`, 1)
+    expect_gte(cph_rot_perf$result$`Integrated C/D AUC`, 0)
+    expect_lte(cph_rot_perf$result$`Integrated Brier score`, 1)
+    expect_gte(cph_rot_perf$result$`Integrated Brier score`, 0)
+    expect_equal(length(cph_rot_perf$result$`Brier score`), length(cph_exp_rot$times))
+    expect_equal(length(cph_rot_perf$result$`C/D AUC`), length(cph_exp_rot$times))
     expect_true(all(cph_rot_perf$eval_times == cph_exp_rot$times))
 
-    expect_lte(rsf_rot_perf$`C-index`, 1)
-    expect_gte(rsf_rot_perf$`C-index`, 0)
-    expect_lte(rsf_rot_perf$`Integrated C/D AUC`, 1)
-    expect_gte(rsf_rot_perf$`Integrated C/D AUC`, 0)
-    expect_lte(rsf_rot_perf$`Integrated Brier score`, 1)
-    expect_gte(rsf_rot_perf$`Integrated Brier score`, 0)
-    expect_equal(length(rsf_rot_perf$`Brier score`), length(rsf_exp_rot$times))
-    expect_equal(length(rsf_rot_perf$`C/D AUC`), length(rsf_exp_rot$times))
+    expect_lte(rsf_rot_perf$result$`C-index`, 1)
+    expect_gte(rsf_rot_perf$result$`C-index`, 0)
+    expect_lte(rsf_rot_perf$result$`Integrated C/D AUC`, 1)
+    expect_gte(rsf_rot_perf$result$`Integrated C/D AUC`, 0)
+    expect_lte(rsf_rot_perf$result$`Integrated Brier score`, 1)
+    expect_gte(rsf_rot_perf$result$`Integrated Brier score`, 0)
+    expect_equal(length(rsf_rot_perf$result$`Brier score`), length(rsf_exp_rot$times))
+    expect_equal(length(rsf_rot_perf$result$`C/D AUC`), length(rsf_exp_rot$times))
     expect_true(all(rsf_rot_perf$eval_times == rsf_exp_rot$times))
 
     expect_output(print(cph_rot_perf))
     expect_output(print(rsf_rot_perf))
 
     plot(cph_rot_perf, rsf_rot_perf)
+    plot(cph_rot_perf, rsf_rot_perf, rug = "events")
+    plot(cph_rot_perf, rsf_rot_perf, rug = "censors")
+    plot(cph_rot_perf, rsf_rot_perf, rug = "none")
     plot(cph_rot_perf, rsf_rot_perf, metrics_type = "scalar")
 
     cph_rot_perf_roc <- model_performance(cph_exp_rot, type = "roc", times = c(100, 200))
